import { IconButton } from '@material-ui/core'
import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import Bill from 'assets/icons/ico/bill.svg'
import CloseIcon from 'assets/icons/ico/close.svg'
import Prm from 'assets/icons/ico/prm.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import React from 'react'

interface SgeModalHintProps {
  open: boolean
  handleCloseClick: () => void
}

const SgeModalHint = ({ open, handleCloseClick }: SgeModalHintProps) => {
  const { t } = useI18n()

  return (
    <Dialog
      open={open}
      disableEscapeKeyDown
      onClose={handleCloseClick}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('auth.enedissgegrandlyon.pdlModal.title_accessibility')}
      </div>
      <IconButton
        aria-label={t('auth.accessibility.button_close')}
        className="modal-paper-close-button"
        onClick={handleCloseClick}
      >
        <Icon icon={CloseIcon} size={16} />
      </IconButton>
      <div className="sgeHintModal">
        <h1 className="text-20-bold">
          {t('auth.enedissgegrandlyon.pdlModal.title')}
        </h1>
        <div className="sgeHintModal-content">
          <p>{t('auth.enedissgegrandlyon.pdlModal.txt1')}</p>
          <p>{t('auth.enedissgegrandlyon.pdlModal.txt2')}</p>
          <div className="bill">
            <Icon icon={Bill} alt="" size={52} />
            <p className="text-16-bold">
              {t('auth.enedissgegrandlyon.pdlModal.txt3')}
            </p>
          </div>
          <p>{t('auth.enedissgegrandlyon.pdlModal.txt4')}</p>
          <Icon
            icon={Prm}
            alt={t('auth.enedissgegrandlyon.pdlModal.prm_accessibility')}
            className="prm"
          />
          <Button
            aria-label={t(
              'auth.enedissgegrandlyon.pdlModal.button_accessibility'
            )}
            onClick={handleCloseClick}
            className="btnPrimary"
          >
            {t('auth.enedissgegrandlyon.pdlModal.button')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default SgeModalHint
