import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { SgeStore } from 'models'
import React from 'react'
import { SGEKeysForm } from './SgeConnectView'

interface StepAddressProps {
  sgeState: SgeStore
  onChange: (key: SGEKeysForm, value: string, maxLength?: number) => void
}

const StepAddress = ({ sgeState, onChange }: StepAddressProps) => {
  const { t } = useI18n()
  return (
    <div className="sge-step-container stepAddress">
      <div className="title text-22-bold">
        {t('auth.enedissgegrandlyon.addressTitle')}
      </div>
      <label htmlFor="address" className="text-16-normal">
        {t('auth.enedissgegrandlyon.address')}
        <input
          type="text"
          id="address"
          name="address"
          className="inputText"
          value={sgeState.address}
          onChange={e => onChange('address', e.target.value)}
        />
      </label>
      <label htmlFor="zipCode" className="text-16-normal">
        {t('auth.enedissgegrandlyon.zipCode')}
        <input
          type="number"
          min={0}
          id="zipCode"
          name="zipCode"
          className="inputText"
          value={sgeState.zipCode !== null ? sgeState.zipCode : undefined}
          onChange={e => onChange('zipCode', e.target.value, 5)}
        />
      </label>

      <label htmlFor="city" className="text-16-normal">
        {t('auth.enedissgegrandlyon.city')}
        <input
          type="text"
          id="city"
          name="city"
          className="inputText"
          value={sgeState.city}
          onChange={e => onChange('city', e.target.value)}
        />
      </label>
    </div>
  )
}

export default StepAddress
