import { render, screen } from '@testing-library/react'
import userEvent from '@testing-library/user-event'
import React from 'react'
import { mockGlobalState } from 'tests/__mocks__/store'
import StepIdentityAndPdl from './StepIdentityAndPdl'

const mockHandleChange = jest.fn()

describe('StepIdentityAndPdl component', () => {
  it('should be rendered correctly', () => {
    const { container } = render(
      <StepIdentityAndPdl
        sgeState={mockGlobalState.sgeConnect}
        onChange={mockHandleChange}
      />
    )
    expect(container).toMatchSnapshot()
  })

  describe('should change fields', () => {
    beforeEach(() => {
      jest.clearAllMocks()
      render(
        <StepIdentityAndPdl
          sgeState={mockGlobalState.sgeConnect}
          onChange={mockHandleChange}
        />
      )
    })
    it('should change firstName value', async () => {
      const firstNameInput = screen.getByRole('textbox', {
        name: 'auth.enedissgegrandlyon.firstName',
      })
      await userEvent.type(firstNameInput, 'n')
      expect(mockHandleChange).toHaveBeenCalledWith('firstName', 'n')
    })
    it('should change lastName value', async () => {
      const lastNameInput = screen.getByRole('textbox', {
        name: 'auth.enedissgegrandlyon.lastName',
      })
      await userEvent.type(lastNameInput, 'n')
      expect(mockHandleChange).toHaveBeenCalledWith('lastName', 'n')
    })
    it('should change pdl value', async () => {
      const pdlInput = screen.getByRole('spinbutton', {
        name: 'auth.enedissgegrandlyon.pdlLabel',
      })
      await userEvent.type(pdlInput, '0')
      expect(mockHandleChange).toHaveBeenCalledWith('pdl', '0', 14)
    })
    it('should open hint modal', async () => {
      const pdlModalButton = screen.getByRole('button', {
        name: 'auth.enedissgegrandlyon.pdlModal.title',
      })
      await userEvent.click(pdlModalButton)
      expect(screen.getByRole('dialog')).toBeInTheDocument()
    })
  })
  it('should have an existing pdl value', () => {
    render(
      <StepIdentityAndPdl
        sgeState={{ ...mockGlobalState.sgeConnect, pdl: 11111111111111 }}
        onChange={mockHandleChange}
      />
    )
    const pdlInput = screen.getByRole('spinbutton', {
      name: 'auth.enedissgegrandlyon.pdlLabel',
    })
    expect(pdlInput).toHaveValue(11111111111111)
  })
})
