import { render } from '@testing-library/react'
import { FluidState, FluidType } from 'enums'
import { GlobalState } from 'models'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore, mockGlobalState } from 'tests/__mocks__/store'
import FluidButton from './FluidButton'

describe('FluidButton component', () => {
  const store = createMockEcolyoStore()

  it('should be rendered correctly', async () => {
    const { container } = render(
      <Provider store={store}>
        <FluidButton fluidType={FluidType.ELECTRICITY} isActive={false} />
      </Provider>
    )
    expect(container).toMatchSnapshot()
  })

  it('should render multifluidButton', () => {
    const { container } = render(
      <Provider store={store}>
        <FluidButton fluidType={FluidType.MULTIFLUID} isActive={false} />
      </Provider>
    )
    const element = container.getElementsByClassName('multifluid').item(0)
    expect(element).toBeInTheDocument()
  })
  it('should render active button', () => {
    const { container } = render(
      <Provider store={store}>
        <FluidButton fluidType={FluidType.GAS} isActive={true} />
      </Provider>
    )
    expect(container.getElementsByClassName('active').length).toBeTruthy()
  })
  it('should render errored button', () => {
    const updatedInitialState: GlobalState = {
      ...mockGlobalState,
    }
    updatedInitialState.fluidStatus[FluidType.GAS].status = FluidState.ERROR
    const store = createMockEcolyoStore({
      global: updatedInitialState,
    })
    const { container } = render(
      <Provider store={store}>
        <FluidButton fluidType={FluidType.GAS} isActive={false} />
      </Provider>
    )
    const element = container.getElementsByClassName('notif-error').item(0)
    expect(element).toBeInTheDocument()
  })
})
