import Button from '@material-ui/core/Button'
import defaultDuelIcon from 'assets/icons/visu/challenge/CHALLENGE0001.svg'
import defaultIcon from 'assets/icons/visu/duel/default.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { UserChallengeUpdateFlag } from 'enums'
import { UserChallenge } from 'models'
import React, { useCallback, useEffect, useState } from 'react'
import ChallengeService from 'services/challenge.service'
import { setChallengeConsumption } from 'store/challenge/challenge.slice'
import { useAppDispatch } from 'store/hooks'
import { formatNumberValues, importIconById } from 'utils/utils'
import './duelUnlocked.scss'

const DuelUnlocked = ({ userChallenge }: { userChallenge: UserChallenge }) => {
  const { t } = useI18n()
  const client = useClient()
  const dispatch = useAppDispatch()

  const [duelIcon, setDuelIcon] = useState(defaultIcon)
  const average: string = formatNumberValues(
    userChallenge.duel.threshold
  ).toString()
  const duration: string = userChallenge.duel.duration.days.toString()
  const description: string = userChallenge.duel.description
    .replace('#CONSUMPTION', average)
    .replace('#DURATION', duration)

  const launchDuel = useCallback(async () => {
    const challengeService = new ChallengeService(client)
    const updatedChallenge = await challengeService.updateUserChallenge(
      userChallenge,
      UserChallengeUpdateFlag.DUEL_START
    )
    const dataloads =
      await challengeService.getUserChallengeDataload(updatedChallenge)
    dispatch(
      setChallengeConsumption({
        userChallenge: updatedChallenge,
        currentDataload: dataloads,
      })
    )
  }, [client, dispatch, userChallenge])

  useEffect(() => {
    async function handleEcogestureIcon() {
      const icon = await importIconById(userChallenge.id, 'challenge')
      setDuelIcon(icon || defaultDuelIcon)
    }
    handleEcogestureIcon()
  }, [userChallenge])

  return (
    <>
      <div className="duel-unlocked-container">
        <StyledIcon className="duel-icon" icon={duelIcon} size={219} />
        <div className="duel-description text-20-italic">{`"${description}"`}</div>
        <div className="duel-title text-16-normal">
          {userChallenge.duel.title}
        </div>
        <div className="duel-average-info text-18-normal">
          {t('duel.average_info', {
            average,
            smartCount: average,
          })}
        </div>
        <div className="button-start">
          <Button
            aria-label={t('duel.accessibility.button_start_duel')}
            onClick={launchDuel}
            className="btnSecondary"
          >
            {t('duel.button_start')}
          </Button>
        </div>
      </div>
    </>
  )
}

export default DuelUnlocked
