import { Button, Collapse } from '@material-ui/core'
import doingIcon from 'assets/icons/ico/doing-enabled.svg'
import objectiveIcon from 'assets/icons/ico/objective-enabled.svg'
import skipIcon from 'assets/icons/ico/skip-enabled.svg'
import defaultIcon from 'assets/icons/visu/ecogesture/default.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { Ecogesture } from 'models'
import React, { useEffect, useState } from 'react'
import { importIconById } from 'utils/utils'
import './ecogestureSelectionDetail.scss'

interface EcogestureSelectionDetailProps {
  ecogesture: Ecogesture
  validate: (objective: boolean, doing: boolean) => void
  title: string
}

const EcogestureSelectionDetail = ({
  ecogesture,
  validate,
  title,
}: EcogestureSelectionDetailProps) => {
  const { t } = useI18n()
  const [ecogestureIcon, setEcogestureIcon] = useState<string>('')
  const [showDetails, setShowDetails] = useState(false)

  useEffect(() => {
    let subscribed = true
    async function getIcon() {
      const icon = await importIconById(ecogesture.id, 'ecogesture')
      if (subscribed) {
        setEcogestureIcon(icon || defaultIcon)
      }
    }
    getIcon()
    setShowDetails(false)
    return () => {
      subscribed = false
    }
  }, [ecogesture.id])

  return (
    <div className="eg-selection-detail-container">
      <div className="content">
        <div className="iconContainer">
          <StyledIcon className="icon" icon={ecogestureIcon} size={240} />
        </div>
        <div className="text-22 title">{title}</div>
        <div className="text-18-bold">{ecogesture.longName}</div>

        <Button
          classes={{
            root: 'btnText showMore',
            label: 'text-15-normal',
          }}
          onClick={() => setShowDetails(prev => !prev)}
        >
          {t(`ecogesture_modal.show_${showDetails ? 'less' : 'more'}`)}
        </Button>

        <Collapse in={showDetails} exit={false}>
          <div className="longDescription text-16-normal-150">
            {ecogesture.longDescription}
          </div>
        </Collapse>
      </div>
      <div className="buttons">
        <Button
          aria-label={t('ecogesture_selection.button_objective')}
          classes={{
            root: 'btnSecondary',
            label: 'text-14-bold',
          }}
          onClick={() => validate(true, false)}
        >
          <StyledIcon icon={objectiveIcon} size={60} />
          {t('ecogesture_selection.button_objective')}
        </Button>
        <Button
          aria-label={t('ecogesture_selection.button_doing')}
          classes={{
            root: 'btnSecondary',
            label: 'text-14-bold',
          }}
          onClick={() => validate(false, true)}
        >
          <StyledIcon icon={doingIcon} size={60} />
          {t('ecogesture_selection.button_doing')}
        </Button>
        <Button
          aria-label={t('ecogesture_selection.button_skip')}
          classes={{
            root: 'btnSecondary',
            label: 'text-14-bold',
          }}
          onClick={() => validate(false, false)}
        >
          <StyledIcon icon={skipIcon} size={60} />
          {t('ecogesture_selection.button_skip')}
        </Button>
      </div>
    </div>
  )
}

export default EcogestureSelectionDetail
