import classNames from 'classnames'
import FormNavigation from 'components/CommonKit/FormNavigation/FormNavigation'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { ProfileTypeStepForm } from 'enums'
import { remove } from 'lodash'
import { ProfileType, ProfileTypeAnswer } from 'models'
import React, { useCallback, useEffect, useState } from 'react'
import { useAppSelector } from 'store/hooks'

interface ProfileTypeFormMultiChoiceProps {
  step: ProfileTypeStepForm
  viewedStep: ProfileTypeStepForm
  currentProfileType: ProfileType
  answerType: ProfileTypeAnswer
  setNextStep: (_profileType: ProfileType) => void
  setPreviousStep: () => void
}

const ProfileTypeFormMultiChoice = ({
  step,
  viewedStep,
  currentProfileType,
  answerType,
  setNextStep,
  setPreviousStep,
}: ProfileTypeFormMultiChoiceProps) => {
  const { t } = useI18n()
  const { isProfileTypeCompleted } = useAppSelector(
    state => state.ecolyo.profile
  )
  const [answer, setAnswer] = useState<string[]>([])

  const handleChange = (value: string) => {
    let tempAnswer = [...answer]
    if (value === 'none' && !tempAnswer.includes(value)) {
      tempAnswer = [value]
    } else if (tempAnswer.includes(value)) {
      remove(tempAnswer, function (n) {
        return n === 'none' || n === value
      })
    } else {
      remove(tempAnswer, function (n) {
        return n === 'none'
      })
      tempAnswer.push(value)
    }
    setAnswer(tempAnswer)
  }

  const isChecked = (value: string): boolean => {
    return answer.includes(value)
  }

  const handlePrevious = useCallback(() => {
    setPreviousStep()
  }, [setPreviousStep])

  const handleNext = useCallback(() => {
    setNextStep({
      ...currentProfileType,
      [answerType.attribute]: answer,
    })
  }, [currentProfileType, setNextStep, answer, answerType.attribute])

  useEffect(() => {
    // Set answer if profileType is completed
    if (step < viewedStep || isProfileTypeCompleted) {
      setAnswer(currentProfileType[answerType.attribute] as string[])
    }
  }, [step, viewedStep, currentProfileType, answerType, isProfileTypeCompleted])

  return (
    <>
      <div className="profile-form-container">
        <div className="profile-question-label">
          {t(
            `profile_type.${ProfileTypeStepForm[step].toLowerCase()}.question`
          )}
        </div>
        <span className="profile-question-hint">
          {t('profile_type.multi_choices')}
        </span>
        {answerType.choices.map((value, index) => {
          if (!value) return null
          const stringValue = value.toString()
          return (
            <label
              key={index}
              className={classNames('checkbox', {
                ['answer-checked']: answer.includes(stringValue),
              })}
            >
              <input
                type="checkbox"
                value={stringValue}
                name={stringValue}
                onChange={() => handleChange(stringValue)}
                checked={isChecked(stringValue)}
              />
              {t(
                `profile_type.${ProfileTypeStepForm[
                  step
                ].toLowerCase()}.${value}`
              )}
            </label>
          )
        })}
      </div>
      <FormNavigation
        handlePrevious={handlePrevious}
        handleNext={handleNext}
        disableNextButton={answer.length < 1}
      />
    </>
  )
}

export default ProfileTypeFormMultiChoice
