/* eslint-disable jsx-a11y/no-autofocus */
import FormNavigation from 'components/CommonKit/FormNavigation/FormNavigation'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { ProfileTypeStepForm } from 'enums'
import { ProfileType, ProfileTypeAnswer, ProfileTypeValues } from 'models'
import React, { useCallback, useEffect, useState } from 'react'
import { useAppSelector } from 'store/hooks'

interface ProfileTypeFormNumberProps {
  step: ProfileTypeStepForm
  viewedStep: ProfileTypeStepForm
  currentProfileType: ProfileType
  answerType: ProfileTypeAnswer
  setNextStep: (_profileType: ProfileType) => void
  setPreviousStep: () => void
}

const ProfileTypeFormNumber = ({
  step,
  viewedStep,
  currentProfileType,
  answerType,
  setNextStep,
  setPreviousStep,
}: ProfileTypeFormNumberProps) => {
  const { t } = useI18n()
  const { isProfileTypeCompleted } = useAppSelector(
    state => state.ecolyo.profile
  )
  const [answer, setAnswer] = useState<ProfileTypeValues>('')

  const handlePrevious = useCallback(() => {
    setPreviousStep()
  }, [setPreviousStep])

  const handleNext = useCallback(() => {
    setNextStep({ ...currentProfileType, [answerType.attribute]: answer })
  }, [currentProfileType, setNextStep, answer, answerType.attribute])

  useEffect(() => {
    if (step < viewedStep || isProfileTypeCompleted) {
      setAnswer(currentProfileType[answerType.attribute])
    }
  }, [step, viewedStep, currentProfileType, answerType, isProfileTypeCompleted])

  return (
    <>
      <div className="profile-form-container">
        <div className="profile-question-label">
          {t(
            `profile_type.${ProfileTypeStepForm[step].toLowerCase()}.question`
          )}
        </div>
        {answer != null && (
          <label className="text">
            <input
              type="number"
              className="inputNumber"
              value={answer.toString()}
              name={answerType.attribute}
              onChange={e => setAnswer(e.target.value)}
              autoFocus
              style={{ marginRight: '0.5rem' }}
            />
            m²
          </label>
        )}
      </div>
      <FormNavigation
        handlePrevious={handlePrevious}
        handleNext={handleNext}
        disableNextButton={answer === ''}
      />
    </>
  )
}

export default ProfileTypeFormNumber
