import { render, screen, waitFor } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import SplashRoot from './SplashRoot'

jest.mock('@sentry/react', () => ({
  ...jest.requireActual('@sentry/react'),
  // mock transaction because the .finish method cannot be called on undefined otherwise
  startTransaction: () => ({ finish: jest.fn() }),
}))

describe('SplashRoot component', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly', async () => {
    const { container } = render(
      <Provider store={store}>
        <SplashRoot>children</SplashRoot>
      </Provider>
    )
    expect(container).toMatchSnapshot()
  })

  it('should render the error screen and click on the reload button', async () => {
    const { container } = render(
      <Provider store={store}>
        <SplashRoot>children</SplashRoot>
      </Provider>
    )
    await waitFor(() => null, { container })
    expect(container).toMatchSnapshot()
    await userEvent.click(screen.getByRole('button'))
  })
})
