import { PayloadAction, createSlice } from '@reduxjs/toolkit'
import { CustomPopup, ModalState } from 'models'

const initialState: ModalState = {
  customPopupModal: {
    popupEnabled: false,
    title: '',
    image: '',
    description: '',
    endDate: '',
  },
  isConnectionModalOpen: false,
  isFeedbacksOpen: false,
  partnersIssueModal: {
    enedis: false,
    egl: false,
    grdf: false,
  },
}

type OpenPartnersModalAction = PayloadAction<{
  egl: boolean
  enedis: boolean
  grdf: boolean
}>

export const modalSlice = createSlice({
  name: 'modal',
  initialState,
  reducers: {
    openFeedbackModal: (state, action: PayloadAction<boolean>) => {
      state.isFeedbacksOpen = action.payload
    },
    openPartnersModal: (state, action: OpenPartnersModalAction) => {
      state.partnersIssueModal = action.payload
    },
    openConnectionModal: (state, action: PayloadAction<boolean>) => {
      state.isConnectionModalOpen = action.payload
    },
    setCustomPopup: (state, action: PayloadAction<CustomPopup>) => {
      state.customPopupModal = action.payload
    },
  },
})

export const {
  openFeedbackModal,
  openPartnersModal,
  setCustomPopup,
  openConnectionModal,
} = modalSlice.actions
